<!--
SPDX-FileCopyrightText: 2020 The cython-sgio Authors

SPDX-License-Identifier: LGPL-2.1-or-later
-->

# cython-sgio

Cython-based wrapper for sending SCSI Generic I/O commands from
Python.

## License

Copyright © 2014-2020 The cython-sgio Authors

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
